@@ -14,7 +14,7 @@
 
 import inject
 
-from superlinked.server.configuration.app_config import AppConfig
+from superlinked.server.configuration.settings import Settings
 from superlinked.server.service.data_loader import DataLoader
 from superlinked.server.service.file_handler_service import FileHandlerService
 from superlinked.server.service.file_object_serializer import FileObjectSerializer
@@ -26,8 +26,8 @@ def register_dependencies() -> None:
 
 
 def _configure(binder: inject.Binder) -> None:
-    app_config = AppConfig()
-    file_handler_service = FileHandlerService(app_config)
+    settings = Settings()
+    file_handler_service = FileHandlerService(settings)
     serializer = FileObjectSerializer(file_handler_service)
-    binder.bind(DataLoader, DataLoader(app_config))
+    binder.bind(DataLoader, DataLoader(settings))
     binder.bind(PersistenceService, PersistenceService(serializer))
