@@ -22,22 +22,24 @@ from beartype.typing import Any
 from pandas.io.json._json import JsonReader
 from pandas.io.parsers import TextFileReader
 from pydantic.alias_generators import to_snake
+
+from superlinked.framework.common.telemetry.telemetry_registry import TelemetryRegistry
 from superlinked.framework.dsl.source.data_loader_source import (
     DataFormat,
     DataLoaderConfig,
     DataLoaderSource,
 )
-
-from superlinked.server.configuration.app_config import AppConfig
+from superlinked.server.configuration.settings import Settings
 from superlinked.server.exception.exception import DataLoaderNotFoundException
 
 logger = structlog.getLogger(__name__)
 
 
 class DataLoader:
-    def __init__(self, app_config: AppConfig) -> None:
-        self._app_config = app_config
+    def __init__(self, settings: Settings) -> None:
+        self._settings = settings
         self._data_loader_sources: dict[str, DataLoaderSource] = {}
+        self._telemetry = TelemetryRegistry()
 
     def register_data_loader_sources(self, data_loader_sources: Sequence[DataLoaderSource]) -> None:
         for source in data_loader_sources:
@@ -71,12 +73,28 @@ class DataLoader:
         if isinstance(data, pd.DataFrame):
             self.__print_memory_usage(data)
             logger.debug("loaded data frame to memory", chunked=False, size=len(data))
-            source.put([data])
+            labels = {
+                "data_loader_name": source.name,
+                "schema": source._schema,
+                "data_format": source.config.format.value,
+                "chunked": False,
+            }
+            with self._telemetry.span("data_loader.put", attributes=labels):
+                source.put([data])
+            self._telemetry.record_metric("ingested_items_with_data_loader_total", len(data), labels=labels)
         elif isinstance(data, TextFileReader | JsonReader):
             for chunk in data:
                 self.__print_memory_usage(chunk)
                 logger.debug("loaded data frame to memory", chunked=True, size=len(chunk))
-                source.put([chunk])
+                labels = {
+                    "data_loader_name": source.name,
+                    "schema": source._schema,
+                    "data_format": source.config.format.value,
+                    "chunked": True,
+                }
+                with self._telemetry.span("data_loader.put", attributes=labels):
+                    source.put([chunk])
+                self._telemetry.record_metric("ingested_items_with_data_loader_total", len(chunk), labels=labels)
         else:
             error_message = (
                 "The returned object from the Pandas read method was not of the "
